#
# spec file for package geotiff
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   5
%define libname lib%{name}%{sover}
Name:           geotiff
Version:        1.7.3
Release:        1.3
Summary:        Library to handle georeferenced TIFF
License:        MIT AND SUSE-Public-Domain
URL:            https://github.com/OSGeo/libgeotiff
Source0:        https://github.com/OSGeo/libgeotiff/releases/download/%{version}/libgeotiff-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(proj) >= 6.0
BuildRequires:  pkgconfig(zlib)

%description
This library is designed to permit the extraction and parsing of the
"GeoTIFF" Key directories, as well as definition and installation of
GeoTIFF keys in new files.

%package devel
Summary:        GeoTIFF header files
Requires:       %{libname} = %{version}
Requires:       pkgconfig(libtiff-4)
Requires:       pkgconfig(proj) >= 6.0
Provides:       lib%{name}-devel = %{version}

%description devel
Header files for GeoTIFF library.

This library is designed to permit the extraction and parsing of the
"GeoTIFF" Key directories, as well as definition and installation of
GeoTIFF keys in new files.

%package -n %{libname}
Summary:        Shared libraries for GeoTIFF library

%description -n %{libname}
Shared libraries for GeoTIFF library.

This library is designed to permit the extraction and parsing of the
"GeoTIFF" Key directories, as well as definition and installation of
GeoTIFF keys in new files.

%prep
%autosetup -n lib%{name}-%{version}

%build
export CFLAGS="%{optflags} $CFLAGS -g -fstack-protector -fno-strict-aliasing -D _BSD_SOURCE"
export CXXFLAGS="%{optflags} $CXXFLAGS -g -fstack-protector -fno-strict-aliasing"
%configure \
	--prefix=%{_prefix} \
	--includedir=%{_includedir}/lib%{name} \
	--with-proj \
	--with-jpeg \
	--with-zip \
	--with-pic \
	--enable-static=no \
	--enable-debug=yes
%make_build

%install
%make_install

# install pkgconfig file
cat > libgeotiff.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}/lib%{name}

Name:           %{libname}
Version:        %{version}
Description: GeoTIFF file format library
Libs: -L%{_libdir} -l%{name}
Cflags: -I%{_includedir}/lib%{name}
EOF

install -Dpm 0644 lib%{name}.pc \
  %{buildroot}%{_libdir}/pkgconfig/lib%{name}.pc
# do not ship la files
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %{libname}

%files
%license LICENSE COPYING
%doc ChangeLog README NEWS
%{_bindir}/geotifcp
%{_bindir}/listgeo
%{_bindir}/applygeo
%{_mandir}/man1/listgeo.1%{?ext_man}
%{_mandir}/man1/applygeo.1%{?ext_man}
%{_mandir}/man1/geotifcp.1%{?ext_man}

%files -n %{libname}
%license LICENSE COPYING
%doc ChangeLog README NEWS
%{_libdir}/lib%{name}.so.%{sover}*

%files devel
%defattr(0644,root,root,0755)
%license LICENSE COPYING
%doc ChangeLog README NEWS
%dir %{_includedir}/lib%{name}
%{_includedir}/lib%{name}/*.h
%{_includedir}/lib%{name}/*.inc
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc

%changelog
* Mon Jul 29 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.7.3:
  * CMake: fix typo in CMAKE_INSTALL_BINDIR install target that affects location of geotiff.dll
- Changes for version 1.7.2:
  * GTIFGetDatumInfoEx(): handle dynamic datums
  * CMake: adopt GNUInstallDirs
  * CMake: export TIFF as a public dependency
  * Add XTIFFClientOpenExt() with re-entrant error callbacks
  * listgeo: add a -no_corners option to avoid printing corner
  * coordinates which might be PROJ version sensitive (refs #81)
  * Fix test failures with PROJ 9.1.1 and 9.3
  * Remove trailing spaces from many files.
  * Localize variables and add const when possible in a number of files
  * geo_normalize.c: sprintf --> snprintf
  * Add missing includes
  * Fix -Werror=calloc-transposed-args with gcc 14
  * FindPROJ.cmake: proj_experimental;h -> proj_experimental.h
  * CMake: add a BUILD_SHARED_LIBS option, and make it default to ON
  * autoconf/CMake: add generation of libgeotiff.pc
  * Remove INSTALL and install-sh autoconf-generated files
* Fri Mar 17 2023 Martin Pluskal <mpluskal@suse.com>
- Update spec file
* Thu May  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.7.1
  * geotiff.h: more precise signature for GTIFDirectoryInfo()
  * applygeo.c/geotifcp.c: use uint16/32_t instead of old libtiff
    non _t custom types
  * Bump CMake min to 3.0.0 and remove apparently unneeded
    cmake_policy() declarations
  * CMake: remove libjpeg and libz from linking of libgeotiff
    itself.
  * geo_config.h: prefix HAVE_xxx and restrict it to
    GEOTIFF_HAVE_STRINGS_H
  * GTIFPrintDefn(): avoid potential nullptr deref. (CID 1469240)
  * CMake: use variable for installation subdirectories, and make
    sure INTERFACE_INCLUDE_DIRECTORIES is exported
  * ReadKey(): only allow reading a key with TIFFTagLocation=0
    that has a count of 1 to avoid reading an illegal address (and
    crashing) when using GTIFKeyGet() or PrintKey()
  * ReadKey(): add extra warning messages
  * CMake: avoid INTERFACE_LINK_LIBRARIES vs
    LINK_INTERFACE_LIBRARIES_DEBUG warning about TIFF
  * CMake: Fix dllexport
  * CMake: Revise exported cmake config wrt BUILD_SHARED_LIBS
  * CMake: Revise exported cmake config wrt dependencies
  * CMake: Respect _FIND_QUIETLY
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Add CoordinateEpochGeoKey = 5120 of type DOUBLE to store coordinate epoch of
    tie points / geotransform matrix for dynamic CRS.
  * geo_normalize.h/c: rename variables to please codespell
  * GTIFGetGCSInfoEx(): use proj_crs_get_datum_forced() for PROJ >= 8 to avoid
    issues with datum ensembles
  * GTIFGetGCSInfoEx(): remove dead code
  * geo_normalize.c: follow-up to e06625c4e5bcce9f9217d1d5a43dc6af73156283 to
    avoid look up of user-defined GeogGeodeticDatumGeoKey that cause PROJ warnings
* Tue Aug 25 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.6.0:
  * Add support for OGC GeoTIFF 1.1
  * Expose GTIFGetPCSInfoEx(), GTIFGetProjTRFInfoEx(), GTIFGetGCSInfoEx(), GTIFGetDatumInfoEx(), GTIFGetEllipsoidInfoEx(), GTIFGetPMInfoEx(), GTIFGetUOMLengthInfoEx() and GTIFGetUOMAngleInfoEx() so that users can specify their own PROJ context
  * Add GTIFKeyGetASCII(), GTIFKeyGetSHORT() and GTIFKeyGetDOUBLE() as safer variants of GTIFKeyGet() with type checking
  * autotools build: enable build in a separate tree from source (#37) (fixes #28)
  * Use pkg-config for libtiff detection
  * GTIFDecToDMS(): fix rounding issue (refs #16)
  * geo_names.c: Silence warning in GetNameFromDatabase
  * cpl_serv.h: add parenthesis in macro definitions
  * Fix spelling errors
  * geo_normalize.c: set UOMLength from GeogLinearUnits (for geocentic CRS) (GDAL #1595)
  * testlistgeo: remove hardcoded path in test output (fixes https://github.com/OSGeo/libgeotiff/issues/16#issuecomment-502267406)
  * Adapt test script for PROJ 6.2 EPSG database (fixes #22)
  * Use unix EOL for cmake related files (fixes #14)
  * configure.ac: drop dead code
  * geo_normalize.c: avoid look up of user-defined geokeys that cause PROJ warnings (fixes GDAL #2321)
  * listgeo: fix corner coordinates for images with RasterPixelIsPoint (#36)
* Sun Jul 21 2019 Dirk Stoecker <opensuse@dstoecker.de>
- Require proj 6.0 also for devel package so it matches the
  build requirements
* Tue Apr  2 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.5.1 (support gdal 2.4.1)
- Remove merged upstream patch f4956251.patch
* Mon Mar 25 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Add upstream patch f4956251.patch to make it useable with gdal
  2.4.1
- Upstream issue https://github.com/OSGeo/libgeotiff/issues/14
  Simplify fixing file (all are utf-8 ok) just CRLF
* Sun Mar 24 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 1.5.
  + Require PROJ >= 6 dependency
  + Remove all CSV files used by geo_normalize API, libgeotiff now
    relies on PROJ database for EPSG CRS definitions.
  + geo_normalize.c: SetGTParmIds(): use
    ProjStraightVertPoleLongGeoKey for CT_PolarStereographic
  + geo_normalize.c: report StdParallel1 for Mercator_2SP when a
    PCS code is used
  + geo_normalize.c: fix support for Laborde Oblique Mercator
  + listgeo: use PROJ database to display non-hardcoded values of
    a number of keys
- Packaging
  + Remove unneeded patches e5cf016.patch 7425a7f.patch
  + Move URL & source to https
* Fri Mar 15 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to bugfix version 1.4.3
- Add upstream patches (proj6 support and build fix)
  + e5cf016.patch
  + 7425a7f.patch
- Packaging: spec-cleaner minimal
* Tue May 29 2018 mpluskal@suse.com
- Fix incorrect library (boo#1094802)
* Sun Mar 12 2017 mpluskal@suse.com
- Small packaging cleanup
- Prepare version update for Leap and backports (boo#1029595)
* Sat Oct  1 2016 tzotsos@opensuse.org
- Update to 1.4.2
  * update to EPSG v8.9 database
  * cleanups and security fixes
* Fri Sep 30 2016 tzotsos@opensuse.org
- Switched download link to OSGeo server
* Tue Jul  5 2016 toddrme2178@gmail.com
- Fix Group tag.
* Sat May  9 2015 mpluskal@suse.com
- Do not build or ship static libraries and .la files
- Remove useless conditions
* Sat Jan 31 2015 mpluskal@suse.com
- Cleanup spec file using spec-cleaner
- Remove commented out patch
- Add build dependency on graphviz to enable images in
  documentation
- Add build dependency on pkg-config to enable dependency generation
  of .pc file
- Update to 1.4.1
  * CMake: Fix up SONAME and VERSION to better
    match configure.ac
  * csv/datum_shift_pref.csv: revert change in preferred datum shift
    for Pulkovo 1942(58) related to ticket #1851 - not appropriate.
  * Preparing 1.4.1 release.
  * csv/datum_shift_pref.csv: Update Pulkova 1942(58) to use a
    particular transformation (#52).
  * bin/geotifcp.c: added B, L, C and M flags from tiffcp (#68)"
  * geo_print.c: clarify that the buffer passed to read methods is only
    guaranteed to be 1024 bytes long (#62).
  * CMake: Support for INCODE build. If you need INCODE support,
    with the definitions compiled into headers, use CMake as your
    configuration/build platform.
  * csv: Override three Brazilian datum shifts on behalf of Daniel
    Miranda and the OSGeo Brazilian Chapter.
  * csv: Upgrade to EPSG 8.5
  * INCODE: Adapt Ben Adler's patch in #66 to add INCODE support to the
    CMake configuration
  * geo_normalize.c: #59, better Mercator_2SP support
  * geotifcp: Do not segfault when a TIFF file has WhitePoint set #65
  * geo_names.c: fix #67 -- add VerticalUnitsGeoKey
  * add_esri_column.py: manually replace D_SIRGAS-Chile by D_Peru96 for GCS_Peru96. Likely an error in the FileGDB SDK db (#63)
  * csv: Upgrade to EPSG 8.4
  * tiffcp: Add bigtiff output support with the -8 flag like tiffcp.  Contributed by
    Mohannad Al-Durgham (nwgeo.com).
  * csv: Upgrade to EPSG 8.2
  * csv/datum_shift_pref.csv: Force OSGB 1936 preferred datum shift.
    (http://trac.osgeo.org/gdal/ticket/4597)
* Fri Jun 15 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Fix in pkgconfig file
* Sat May 26 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Updated to 1.4.0
* Thu Mar 22 2012 Michael Behrisch <behrisch@users.sf.net>
- added gcc build dependency
- removed unneeded data dir fix for non-Suse
* Mon Apr 11 2011 Rene van Paassen<rene.vanpaassen@gmail.com>
- removed now superfluous "%%exclude %%{_libdir}/debug" for i586
* Sat Apr  9 2011 Hans-Peter Jansen <hpj@urpla.net>
- fix 64 bit issues, enable debug
* Thu Jul  8 2010 Dirk Stöcker <opensuse@dstoecker.de> 1.3.0
- Updated to 1.3.0
* Fri Jun 26 2009 Dirk Stöcker <opensuse@dstoecker.de> 1.2.5
- Updated to 1.2.5
- Using parts of spec file from PackMan for improved quality
* Mon Jun  9 2008 Dirk Stöcker <opensuse@dstoecker.de> 1.2.4
- SPEC file created for openSUSE build service
* Sat Jul 14 2007 judas_iscariote@shorewall.net
- spec file cleanup
  Mon Jun 19 12:00:00 UTC 2006 - Tim Fischer
- SPEC file created for SUSE 10.1
